@@ -3,14 +3,12 @@ package dpkg
 import (
 	"fmt"
 
-	syftPkg "github.com/anchore/syft/syft/pkg"
-
 	"github.com/anchore/grype/grype/distro"
 	"github.com/anchore/grype/grype/match"
-	"github.com/anchore/grype/grype/matcher/common"
 	"github.com/anchore/grype/grype/pkg"
+	"github.com/anchore/grype/grype/search"
 	"github.com/anchore/grype/grype/vulnerability"
-	"github.com/jinzhu/copier"
+	syftPkg "github.com/anchore/syft/syft/pkg"
 )
 
 type Matcher struct {
@@ -27,13 +25,13 @@ func (m *Matcher) Type() match.MatcherType {
 func (m *Matcher) Match(store vulnerability.Provider, d *distro.Distro, p pkg.Package) ([]match.Match, error) {
 	matches := make([]match.Match, 0)
 
-	sourceMatches, err := m.matchBySourceIndirection(store, d, p)
+	sourceMatches, err := m.matchUpstreamPackages(store, d, p)
 	if err != nil {
 		return nil, fmt.Errorf("failed to match by source indirection: %w", err)
 	}
 	matches = append(matches, sourceMatches...)
 
-	exactMatches, err := common.FindMatchesByPackageDistro(store, d, p, m.Type())
+	exactMatches, err := search.ByPackageDistro(store, d, p, m.Type())
 	if err != nil {
 		return nil, fmt.Errorf("failed to match by exact package name: %w", err)
 	}
@@ -42,39 +40,20 @@ func (m *Matcher) Match(store vulnerability.Provider, d *distro.Distro, p pkg.Pa
 	return matches, nil
 }
 
-func (m *Matcher) matchBySourceIndirection(store vulnerability.ProviderByDistro, d *distro.Distro, p pkg.Package) ([]match.Match, error) {
-	metadata, ok := p.Metadata.(pkg.DpkgMetadata)
-	if !ok {
-		return nil, nil
-	}
+func (m *Matcher) matchUpstreamPackages(store vulnerability.ProviderByDistro, d *distro.Distro, p pkg.Package) ([]match.Match, error) {
+	var matches []match.Match
 
-	// ignore packages without source indirection hints
-	if metadata.Source == "" {
-		return []match.Match{}, nil
-	}
-
-	// use source package name for exact package name matching
-	var indirectPackage pkg.Package
-
-	err := copier.Copy(&indirectPackage, p)
-	if err != nil {
-		return nil, fmt.Errorf("failed to copy package: %w", err)
-	}
-
-	// use the source package name
-	indirectPackage.Name = metadata.Source
-
-	matches, err := common.FindMatchesByPackageDistro(store, d, indirectPackage, m.Type())
-	if err != nil {
-		return nil, fmt.Errorf("failed to find vulnerabilities by dpkg source indirection: %w", err)
+	for _, indirectPackage := range pkg.UpstreamPackages(p) {
+		indirectMatches, err := search.ByPackageDistro(store, d, indirectPackage, m.Type())
+		if err != nil {
+			return nil, fmt.Errorf("failed to find vulnerabilities for dpkg upstream source package: %w", err)
+		}
+		matches = append(matches, indirectMatches...)
 	}
 
 	// we want to make certain that we are tracking the match based on the package from the SBOM (not the indirect package)
 	// however, we also want to keep the indirect package around for future reference
-	for idx := range matches {
-		matches[idx].Type = match.ExactIndirectMatch
-		matches[idx].Package = p
-	}
+	match.ConvertToIndirectMatches(matches, p)
 
 	return matches, nil
 }
