@@ -115,6 +115,19 @@ func TestNew(t *testing.T) {
 					SourceRpm: "sqlite-3.26.0-6.el8.src.rpm",
 				},
 			},
+			metadata: RpmMetadata{},
+		},
+		{
+			name: "rpm with modularity label",
+			syftPkg: syftPkg.Package{
+				Name:         "sqlite",
+				MetadataType: syftPkg.RpmMetadataType,
+				Metadata: syftPkg.RpmMetadata{
+					SourceRpm:       "sqlite-3.26.0-6.el8.src.rpm",
+					ModularityLabel: "abc:2",
+				},
+			},
+			metadata: RpmMetadata{ModularityLabel: "abc:2"},
 		},
 		{
 			name: "java pkg",
@@ -300,10 +313,24 @@ func TestNew(t *testing.T) {
 		{
 			name: "cpp conan-metadata",
 			syftPkg: syftPkg.Package{
-				MetadataType: syftPkg.ConanaMetadataType,
+				MetadataType: syftPkg.ConanMetadataType,
 				Metadata: syftPkg.ConanMetadata{
-					Name:    "name",
-					Version: "version",
+					Ref: "catch2/2.13.8",
+				},
+			},
+		},
+		{
+			name: "cpp conan lock metadata",
+			syftPkg: syftPkg.Package{
+				MetadataType: syftPkg.ConanLockMetadataType,
+				Metadata: syftPkg.ConanLockMetadata{
+					Ref: "zlib/1.2.12",
+					Options: map[string]string{
+						"fPIC":   "True",
+						"shared": "False",
+					},
+					Path:    "all/conanfile.py",
+					Context: "host",
 				},
 			},
 		},
